from packaging_tutorial.lanedetection.model import test1


def cc(x,y):
    a = test1.bb(x,y)
    return a


